@@ -1,4 +1,3 @@
-use crate::group::PARENTS;
 use crate::prelude::*;
 use crate::{enums::*, widget::Widget};
 use wasm_bindgen::JsValue;
@@ -22,11 +21,7 @@ impl Link {
 impl WidgetBase for Link {
     fn default() -> Self {
         let inner = Widget::new(WidgetType::A);
-        PARENTS.with(|p| {
-            if let Some(last) = p.borrow().last() {
-                last.append(&inner);
-            }
-        });
+        crate::group::Group::current_attach(&inner);
         Self { inner }
     }
     fn default_fill() -> Self {
